pylero.subterra_uri — pylero documentation

# Source code for pylero.subterra_uri

    from __future__ import absolute_import
    from __future__ import division
    from __future__ import print_function
    from __future__ import unicode_literals

    from pylero.base_polarion import BasePolarion

    # Unknown what this class object is supposed to do. Will determine during
    # more intensive testing
    class SubterraURI(BasePolarion):
        def __init__(self):
            pass

    class ArrayOfSubterraURI(BasePolarion):
        def __init__(self):
            pass